pybedtools.contrib.plotting.BedToolsDemo
========================================

.. currentmodule:: pybedtools.contrib.plotting

.. autoclass:: BedToolsDemo

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~BedToolsDemo.__init__
      ~BedToolsDemo.plot
   
   

   
   
   